abacusai.api_class.abstract — AbacusAI documentation

# `abacusai.api_class.abstract`

## Module Contents

### Classes

`ApiClass` | Helper class that provides a standard way to create an ABC using
`_ApiClassFactory` | Helper class that provides a standard way to create an ABC using

### Functions

`camel_case`(value) |

abacusai.api_class.abstract.camel_case(value)

class abacusai.api_class.abstract.ApiClass

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  __post_init__()
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –

class abacusai.api_class.abstract._ApiClassFactory

  Bases: `abc.ABC`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key
  config_class_map
  classmethod from_dict(config)
    Parameters:

      config (dict) –

    Return type:

      ApiClass